@@ -219,29 +219,36 @@ class ImageFolder(Dataset):
             
         return class_idx
 
+
     def _collect_paths(self):
+        """Collect image paths and their class labels, skipping hidden files/dirs."""
         if not os.path.exists(self.root) or not os.path.isdir(self.root):
             raise ValueError(f"Root directory {self.root} does not exist or is not a directory")
-        
-        for class_name in os.listdir(self.root):
+        # Method 1: Class folders (ImageNet style)
+        for class_name in sorted(os.listdir(self.root)):
+            if class_name.startswith('.'):
+                continue
             class_path = os.path.join(self.root, class_name)
             if not os.path.isdir(class_path):
                 continue
             
             for ext in IMG_EXTS:
-                pattern = os.path.join(class_path, f"*{ext}")
-                for img_path in glob.glob(pattern):
-                    self.images.append(img_path)
-                    self.targets.append(class_name)
-        
+                for img_path in glob.glob(os.path.join(class_path, f"*{ext}")):
+                    if not os.path.basename(img_path).startswith('.'):
+                        self.images.append(img_path)
+                        self.targets.append(class_name)
+        # Method 2: Fallback if no class folders found
         if not self.images:
-            for r, _, files in os.walk(self.root):
-                for f in files:
-                    if any(f.lower().endswith(ext) for ext in IMG_EXTS):
-                        p = os.path.join(r, f)
-                        cls = os.path.basename(os.path.dirname(p))
-                        self.images.append(p)
-                        self.targets.append(cls)
+            for root, dirs, files in os.walk(self.root, topdown=True):
+                dirs[:] = [d for d in dirs if not d.startswith('.')]
+                for filename in sorted(files):
+                    if filename.startswith('.') or not any(filename.lower().endswith(ext) for ext in IMG_EXTS):
+                        continue
+                    path = os.path.join(root, filename)
+                    class_label = os.path.basename(os.path.dirname(path))
+                    self.images.append(path)
+                    self.targets.append(class_label)
+
 
     def get_dali_pipeline(self, batch_size: int, shuffle: bool = True, 
                           device: str = "cpu", num_threads: int = 4, 
@@ -579,18 +586,18 @@ def create_dali_transforms(
                 images,
                 device=device,
                 size=random_resized_crop_size,
-                scale=[0.08, 1.0],  # Standard scale range for ImageNet
-                ratio=[0.75, 1.333], # Standard aspect ratio range
+                random_area=[0.08, 1.0],  # Standard scale range for ImageNet
+                random_aspect_ratio=[0.75, 1.333], # Standard aspect ratio range
                 interp_type=types.INTERP_LINEAR
             )
             
         if brightness or contrast or saturation or hue:
             images = fn.color_twist(
                 images, device=device,
-                brightness=fn.random.uniform(range=[-brightness, brightness]),
-                contrast=fn.random.uniform(range=[1-contrast, 1+contrast]),
-                saturation=fn.random.uniform(range=[1-saturation, 1+saturation]),
-                hue=fn.random.uniform(range=[-hue, hue]),
+                brightness=fn.random.uniform(range=[1.0 - brightness, 1.0 + brightness]),
+                contrast=fn.random.uniform(range=[1.0 - contrast, 1.0 + contrast]),
+                saturation=fn.random.uniform(range=[1.0 - saturation, 1.0 + saturation]),
+                hue=fn.random.uniform(range=[-hue, hue]),  # hue is already in degrees
             )
         if horizontal_flip_prob > 0.0:
             images = fn.flip(images, device=device, horizontal=fn.random.coin_flip(probability=horizontal_flip_prob))
